@@ -1,7 +1,7 @@
 package Parse::Dexcom::Tab::Reading;
 use Moose;
 use Moose::Util::TypeConstraints;
-use DatTime;
+use DateTime;
 use Date::Parse;
 
 subtype 'Parse::Dexcom::Tab::Reading::DateTimeType';
